@@ -3,10 +3,10 @@
 /* ========================================================================
  *
  * @license This source file is subject to version 3.01 of the PHP license,
- *      		that is available at http://www.php.net/license/3_01.txt
- *      		If you did not receive a copy of the PHP license and are unable 
- *      		to obtain it through the world-wide-web, please send a note to 
- *      		license@php.net so we can mail you a copy immediately.  
+ *              that is available at http://www.php.net/license/3_01.txt
+ *              If you did not receive a copy of the PHP license and are unable 
+ *              to obtain it through the world-wide-web, please send a note to 
+ *              license@php.net so we can mail you a copy immediately.  
  *
  * @category   Application of MyNETS
  * @project    OpenPNE UsagiProject 2006-2007
@@ -69,9 +69,38 @@ function db_diary_public_flag_condition($c_member_id, $u = null, $force = null)
  */
 function db_diary_get_c_diary4id($c_diary_id)
 {
-    $sql = 'SELECT * FROM c_diary WHERE c_diary_id = ?';
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_diary_id = ?';
     return db_get_row($sql, array(intval($c_diary_id)));
 }
+/**
+ * 日記IDから日記を取得(該当日記の前後の日記IDも取得。)
+ *
+ * @param   int   $c_diary_id
+ * @param   int   $c_member_id(閲覧者)
+ * @return  array
+ * @author shinji hyodo
+ */
+function db_diary_get_c_diary4id_with_prev_next($c_diary_id,$c_member_id)
+{
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_diary_id = ?';
+    $c_diary = db_get_row($sql, array(intval($c_diary_id)));
+    if ($c_diary) {
+        $pf_conf = '';
+        if ($c_member_id != $c_diary['c_member_id']) {
+            $pf_cond = db_diary_public_flag_condition($c_diary['c_member_id'], $c_member_id);
+        }
+        //前の日記
+        $sql = 'SELECT c_diary_id FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ?' . $pf_cond .
+        ' AND c_diary_id < ? ORDER BY c_diary_id DESC';
+        $params = array(intval($c_diary['c_member_id']),intval($c_diary_id));
+        $c_diary['c_diary_id_prev'] = db_get_one($sql,$params);
+        //後の日記
+        $sql = 'SELECT c_diary_id FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ?' . $pf_cond .
+        ' AND c_diary_id > ? ORDER BY c_diary_id';
+        $c_diary['c_diary_id_next'] = db_get_one($sql, $params);
+    }
+    return $c_diary;
+}
 
 /**
  * メンバーIDから日記リストを最新順で取得
@@ -82,7 +111,7 @@ function db_diary_get_c_diary4id($c_diary_id)
 function db_diary_get_c_diary_list4c_member_id($target_c_member_id, $count = 10, $u = null, $force = null)
 {
     $pf_cond = db_diary_public_flag_condition($target_c_member_id, $u, $force);
-    $sql = 'SELECT * FROM c_diary WHERE c_member_id = ?' . $pf_cond .
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ?' . $pf_cond .
            ' ORDER BY r_datetime DESC';
     $params = array(intval($target_c_member_id));
     $arr = db_get_all_limit($sql, 0, $count, $params);
@@ -94,7 +123,7 @@ function db_diary_get_c_diary_list4c_member_id($target_c_member_id, $count = 10,
 
 function p_common_is_active_c_diary_id($c_diary_id)
 {
-    $sql = 'SELECT c_diary_id FROM c_diary WHERE c_diary_id = ?';
+    $sql = 'SELECT c_diary_id FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_diary_id = ?';
     return (bool)db_get_one($sql, array(intval($c_diary_id)));
 }
 
@@ -106,13 +135,14 @@ function p_common_is_active_c_diary_id($c_diary_id)
  * @param   int $c_diary_id
  * @param   int $limit
  * @return  array 日記コメント＋ニックネーム
+ * コメント取得後配列で名前を当てはめるようにいずれ変更する
  */
 function db_diary_get_c_diary_comment_list4c_diary_id($c_diary_id)
 {
-    $sql = 'SELECT c_member.nickname, c_member.image_filename, c_diary_comment.*' .
-        ' FROM c_diary_comment LEFT JOIN c_member USING (c_member_id)' .
-        ' WHERE c_diary_id = ?' .
-        ' ORDER BY c_diary_comment.r_datetime';
+    $sql = 'SELECT cm.nickname, cm.image_filename, cd.*' .
+        ' FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment as cd LEFT JOIN ' . MYNETS_PREFIX_NAME . 'c_member as cm USING (c_member_id)' .
+        ' WHERE cd.c_diary_id = ?' .
+        ' ORDER BY cd.r_datetime';
     return db_get_all($sql, array(intval($c_diary_id)));
 }
 
@@ -133,7 +163,7 @@ function db_diary_get_c_diary_comment_list4id_list($id_list, $page = 1, $page_si
     }
     $e_id_list = implode(',', array_map('intval', (array)$id_list));
 
-    $sql = 'SELECT * FROM c_diary_comment' .
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment' .
             ' WHERE c_diary_comment_id IN ('.$e_id_list.')';
     if ($desc) {
         $sql .= ' ORDER BY r_datetime DESC';
@@ -146,7 +176,7 @@ function db_diary_get_c_diary_comment_list4id_list($id_list, $page = 1, $page_si
         $c_diary_comment_list[$key]['nickname'] = $c_member['nickname'];
     }
 
-    $sql = 'SELECT COUNT(*) FROM c_diary_comment' .
+    $sql = 'SELECT COUNT(*) FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment' .
         ' WHERE c_diary_comment_id IN ('.$e_id_list.')';
     $total_num = db_get_one($sql);
 
@@ -176,8 +206,7 @@ function db_diary_get_c_diary_comment_list4id_list($id_list, $page = 1, $page_si
  */
 function db_diary_count_c_diary_comment4c_diary_id($c_diary_id)
 {
-    //$sql = 'SELECT COUNT(*) FROM c_diary_comment WHERE c_diary_id = ?';
-    $sql = 'SELECT comment_count FROM c_diary WHERE c_diary_id = ?';
+    $sql = 'SELECT comment_count FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_diary_id = ?';
     return db_get_one($sql, array(intval($c_diary_id)));
 }
 
@@ -195,16 +224,15 @@ function db_diary_count_c_diary_comment4c_diary_id($c_diary_id)
 function p_fh_diary_list_diary_list4c_member_id($c_member_id, $page_size, $page, $u = null)
 {
     $pf_cond = db_diary_public_flag_condition($c_member_id, $u);
-    $sql = 'SELECT * FROM c_diary WHERE c_member_id = ?' . $pf_cond .
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ?' . $pf_cond .
            ' ORDER BY r_datetime DESC';
     $params = array(intval($c_member_id));
     $list = db_get_all_page($sql, $page, $page_size, $params);
 
-    foreach ($list as $key=>$value) {
-        $list[$key]['num_comment'] = $value['comment_count'];
-    }
-//コメントカウントの名前が違う！
-    $sql = 'SELECT COUNT(*) FROM c_diary WHERE c_member_id = ?' . $pf_cond;
+    //foreach ($list as $key=>$value) {
+    //    $list[$key]['num_comment'] = $value['comment_count'];
+    //}
+    $sql = 'SELECT COUNT(*) FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ?' . $pf_cond;
     $total_num = db_get_one($sql, $params);
 
     if ($total_num != 0) {
@@ -231,9 +259,8 @@ function p_h_diary_list_friend_h_diary_list_friend4c_member_id($c_member_id, $pa
 {
     $friends = db_friend_c_member_id_list($c_member_id, true);
     $ids = implode(',', array_map('intval', $friends));
-
-    $hint = db_mysql_hint('USE INDEX (r_datetime_c_member_id, r_datetime)');
-    $sql = 'SELECT * FROM c_diary' . $hint .
+    
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary' .
             ' WHERE c_member_id IN (' . $ids . ')' .
             ' AND public_flag <> \'private\'' .
             ' ORDER BY c_diary.r_datetime DESC';
@@ -241,14 +268,13 @@ function p_h_diary_list_friend_h_diary_list_friend4c_member_id($c_member_id, $pa
     $lst = db_get_all_page($sql, $page, $page_size);
 
     foreach ($lst as $key=>$value) {
-        //$lst[$key]['count_comments'] = $value['comment_count'];				//不要と思われるセットを削除
         $lst[$key]['c_member'] = db_common_c_member4c_member_id($value['c_member_id']);
     }
 
-    $sql = 'SELECT count(*) FROM c_diary' .
+    $sql = 'SELECT count(*) FROM ' . MYNETS_PREFIX_NAME . 'c_diary' .
            ' WHERE c_member_id IN (' . $ids . ')' .
            ' AND public_flag <> \'private\'';
-    $total_num = db_get_one($sql);				//不要のparamsを削除
+    $total_num = db_get_one($sql);              //不要のparamsを削除
 
     if ($total_num != 0) {
         $total_page_num =  ceil($total_num / $page_size);
@@ -276,7 +302,7 @@ function p_h_diary_list_friend_h_diary_list_friend4c_member_id($c_member_id, $pa
  */
 function p_h_diary_count_c_diary_not_is_read4c_member_id($c_member_id)
 {
-    $sql = 'SELECT COUNT(*) FROM c_diary WHERE c_member_id = ? AND is_checked = 0';
+    $sql = 'SELECT COUNT(*) FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ? AND is_checked = 0';
     $params = array(intval($c_member_id));
     return db_get_one($sql, $params);
 }
@@ -289,7 +315,7 @@ function p_h_diary_count_c_diary_not_is_read4c_member_id($c_member_id)
  */
 function p_h_diary_c_diary_first_diary_read4c_member_id($c_member_id)
 {
-    $sql = 'SELECT c_diary_id FROM c_diary WHERE c_member_id = ? AND is_checked = 0 ORDER BY r_datetime';
+    $sql = 'SELECT c_diary_id FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ? AND is_checked = 0 ORDER BY r_datetime';
     $params = array(intval($c_member_id));
     return db_get_one($sql, $params);
 }
@@ -306,8 +332,7 @@ function p_h_home_c_diary_friend_list4c_member_id($c_member_id, $limit)
 {
     $friends = db_friend_c_member_id_list($c_member_id, true);
     $ids = implode(',', array_map('intval', $friends));
-
-    $sql = 'SELECT * FROM c_diary' .
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary' .
             ' WHERE c_member_id IN (' . $ids . ')' .
             ' AND public_flag <> \'private\'' .
             ' ORDER BY r_datetime DESC';
@@ -337,13 +362,12 @@ function p_h_home_c_diary_my_comment_list4c_member_id($c_member_id, $limit)
     $blocked = db_member_access_block_list4c_member_id_to($c_member_id);
     $blocked[] = $c_member_id;
     $except_ids = implode(',', $blocked);
-
-    $sql = 'SELECT c_diary_comment.c_diary_id' .
-            ' FROM c_diary_comment INNER JOIN c_diary USING (c_diary_id)' .
-            ' WHERE c_diary_comment.c_member_id = ?' .
-            ' AND c_diary_comment.r_datetime > ?' .
-            ' AND c_diary.c_member_id NOT IN (' . $except_ids . ')' .
-            ' AND c_diary.public_flag <> \'private\'';
+    $sql = 'SELECT dc.c_diary_id' .
+            ' FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment as dc INNER JOIN ' . MYNETS_PREFIX_NAME . 'c_diary as cd USING (c_diary_id)' .
+            ' WHERE dc.c_member_id = ?' .
+            ' AND dc.r_datetime > ?' .
+            ' AND cd.c_member_id NOT IN (' . $except_ids . ')' .
+            ' AND cd.public_flag <> \'private\'';
     $params = array(intval($c_member_id), $date);
     $c_diary_id_list = db_get_col($sql, $params);
     $c_diary_id_list = array_unique($c_diary_id_list);
@@ -353,7 +377,7 @@ function p_h_home_c_diary_my_comment_list4c_member_id($c_member_id, $limit)
 
     $ids = implode(',', $c_diary_id_list);
     $sql = 'SELECT c_diary_id, MAX(r_datetime) as maxdate' .
-           ' FROM c_diary_comment' .
+           ' FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment' .
            ' WHERE c_diary_id IN (' . $ids . ')' .
            ' GROUP BY c_diary_id' .
            ' ORDER BY maxdate DESC';
@@ -367,10 +391,8 @@ function p_h_home_c_diary_my_comment_list4c_member_id($c_member_id, $limit)
         }
         $item += db_common_c_member4c_member_id_LIGHT($item['c_member_id']);
         $item['r_datetime'] = $r_datetime;
-        //$item['num_comment'] = db_diary_count_c_diary_comment4c_diary_id($c_diary_id);
         $result[] = $item;
     }
-//又コメントカウントの名前が違う！
     return $result;
 }
 
@@ -382,16 +404,15 @@ function p_h_diary_comment_list_c_diary_my_comment_list4c_member_id($c_member_id
 
     $friends = db_friend_c_member_id_list($c_member_id);
     $friend_ids = implode(',', $friends);
-
     $sql = 'SELECT d.c_diary_id' .
             ', d.subject' .
             ', d.c_member_id' .
             ', MAX(dc.r_datetime) AS r_datetime' .
             ', d.comment_count' .
-	    ', d.etsuran_count' .
-        ' FROM c_diary AS d' .
-            ' INNER JOIN c_diary_comment AS dc USING (c_diary_id)' .
-            ', c_diary_comment AS mydc' .
+        ', d.etsuran_count' .
+        ' FROM ' . MYNETS_PREFIX_NAME . 'c_diary AS d' .
+            ' INNER JOIN ' . MYNETS_PREFIX_NAME . 'c_diary_comment AS dc USING (c_diary_id)' .
+            ', ' . MYNETS_PREFIX_NAME . 'c_diary_comment AS mydc' .
         ' WHERE mydc.c_member_id = ?' .
             ' AND mydc.c_diary_id = d.c_diary_id' .
             ' AND mydc.c_member_id <> d.c_member_id' .
@@ -408,9 +429,9 @@ function p_h_diary_comment_list_c_diary_my_comment_list4c_member_id($c_member_id
     }
 
     $sql = 'SELECT COUNT(DISTINCT d.c_diary_id)' .
-        ' FROM c_diary AS d' .
-            ' INNER JOIN c_diary_comment AS dc USING (c_diary_id)' .
-            ', c_diary_comment AS mydc' .
+        ' FROM ' . MYNETS_PREFIX_NAME . 'c_diary AS d' .
+            ' INNER JOIN ' . MYNETS_PREFIX_NAME . 'c_diary_comment AS dc USING (c_diary_id)' .
+            ', ' . MYNETS_PREFIX_NAME . 'c_diary_comment AS mydc' .
         ' WHERE mydc.c_member_id = ?' .
             ' AND mydc.c_diary_id = d.c_diary_id' .
             ' AND mydc.c_member_id <> d.c_member_id' .
@@ -439,9 +460,8 @@ function p_fh_diary_list_diary_list_date4c_member_id($c_member_id, $year, $month
         $s_date = date('Y-m-d H:i:s', mktime(0, 0, 0, $month, 1, $year));
         $e_date = date('Y-m-d H:i:s', mktime(0, 0, 0, $month+1, 1, $year));
     }
-
     $pf_cond = db_diary_public_flag_condition($c_member_id, $u);
-    $sql = 'SELECT * FROM c_diary' .
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary' .
             ' WHERE c_member_id = ? AND r_datetime >= ? AND r_datetime < ?' . $pf_cond .
             ' ORDER BY r_datetime DESC';
     $params = array(intval($c_member_id), $s_date, $e_date);
@@ -461,7 +481,7 @@ function p_fh_diary_list_diary_list_date4c_member_id($c_member_id, $year, $month
  */
 function p_fh_diary_list_date_list4c_member_id($c_member_id)
 {
-    $sql = "SELECT r_datetime FROM c_diary" .
+    $sql = "SELECT r_datetime FROM " . MYNETS_PREFIX_NAME . "c_diary" .
         " WHERE c_member_id = ?" .
         " ORDER BY r_datetime";
     $params = array(intval($c_member_id));
@@ -498,7 +518,7 @@ function p_fh_diary_list_date_list4c_member_id($c_member_id)
 //c_member_id から自分の日記についてるコメントID(複数)を取得
 function p_fh_diary_c_diary_comment_id_list4c_member_id($c_member_id)
 {
-    $sql = "SELECT cdc.c_diary_comment_id FROM c_diary as cd,c_diary_comment as cdc" .
+    $sql = "SELECT cdc.c_diary_comment_id FROM " . MYNETS_PREFIX_NAME . "c_diary as cd, " . MYNETS_PREFIX_NAME . "c_diary_comment as cdc" .
         " WHERE cd.c_member_id = ?".
         " AND cd.c_diary_id = cdc.c_diary_id";
     $params = array(intval($c_member_id));
@@ -510,7 +530,7 @@ function p_fh_diary_c_diary_comment_id_list4c_member_id($c_member_id)
  */
 function p_fh_diary_list_calendar_list4c_member_id($year, $month, $c_member_id)
 {
-    $sql = "SELECT cdc.c_diary_comment_id FROM c_diary as cd,c_diary_comment as cdc" .
+    $sql = "SELECT cdc.c_diary_comment_id FROM " . MYNETS_PREFIX_NAME . "c_diary as cd, " . MYNETS_PREFIX_NAME . "c_diary_comment as cdc" .
         " WHERE cd.c_member_id = ?".
         " AND cd.c_diary_id = cdc.c_diary_id";
     $params = array(intval($c_member_id));
@@ -525,7 +545,7 @@ function p_fh_diary_list_calendar_list4c_member_id($year, $month, $c_member_id)
 function p_h_diary_list_all_search_c_diary4c_diary($keyword, $page_size, $page)
 {
     $select = 'SELECT *';
-    $from = ' FROM c_diary';
+    $from = ' FROM ' . MYNETS_PREFIX_NAME . 'c_diary';
     $where = " WHERE public_flag = 'public'";
 
     //and検索を実装
@@ -579,9 +599,8 @@ function p_h_diary_list_all_search_c_diary4c_diary($keyword, $page_size, $page)
 function p_h_diary_is_diary_written_list4date($year, $month, $c_member_id, $u = null)
 {
     include_once 'Date/Calc.php';
-
     $pf_cond = db_diary_public_flag_condition($c_member_id, $u);
-    $sql = 'SELECT DISTINCT DAYOFMONTH(r_datetime) FROM c_diary' .
+    $sql = 'SELECT DISTINCT DAYOFMONTH(r_datetime) FROM ' . MYNETS_PREFIX_NAME . 'c_diary' .
            ' WHERE c_member_id = ? AND r_datetime >= ? AND r_datetime < ?' . $pf_cond;
 
     $date_format = '%Y-%m-%d 00:00:00';
@@ -605,7 +624,7 @@ function p_h_diary_is_diary_written_list4date($year, $month, $c_member_id, $u =
 function _do_c_diary_comment4c_diary_comment_id($c_diary_comment_id)
 {
     $sql = "SELECT dc.*, d.c_member_id AS c_member_id_author,d.c_diary_id";
-    $sql .= " FROM c_diary_comment AS dc, c_diary AS d";
+    $sql .= " FROM " . MYNETS_PREFIX_NAME . "c_diary_comment AS dc, " . MYNETS_PREFIX_NAME . "c_diary AS d";
     $sql .= " WHERE dc.c_diary_comment_id = ?";
     $sql .= " AND dc.c_diary_id = d.c_diary_id";
     $params = array(intval($c_diary_comment_id));
@@ -619,7 +638,7 @@ function k_p_f_home_c_diary_list4c_member_id($c_member_id, $limit)
 {
     //日記リスト
     $sql = "SELECT c_diary_id, r_date, subject ,image_filename_1";
-    $sql .= " FROM c_diary";
+    $sql .= " FROM " . MYNETS_PREFIX_NAME . "c_diary";
     $sql .= " WHERE c_member_id = ?";
     $sql .= " ORDER BY r_date DESC";
     $params = array(intval($c_member_id));
@@ -630,7 +649,7 @@ function k_p_f_home_c_diary_list4c_member_id($c_member_id, $limit)
         $c_diary_id = $value['c_diary_id'];
 
         $sql = "SELECT COUNT(*) ";
-        $sql .= "FROM c_diary_comment ";
+        $sql .= "FROM " . MYNETS_PREFIX_NAME . "c_diary_comment ";
         $sql .= "WHERE c_diary_id = ?";
         $params = array(intval($c_diary_id));
         $c_diary_list[$key]['count_comment'] = db_get_one($sql, $params);
@@ -644,7 +663,7 @@ function k_p_f_home_c_diary_list4c_member_id($c_member_id, $limit)
  */
 function k_p_fh_diary_list_c_diary_list4c_member_id($c_member_id, $page_size, $page)
 {
-    $sql = 'SELECT * FROM c_diary WHERE c_member_id = ? ORDER BY r_datetime DESC';
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ? ORDER BY r_datetime DESC';
     $params = array(intval($c_member_id));
     $c_diary_list = db_get_all_page($sql, $page, $page_size, $params);
 
@@ -653,7 +672,7 @@ function k_p_fh_diary_list_c_diary_list4c_member_id($c_member_id, $page_size, $p
             db_diary_count_c_diary_comment4c_diary_id($value['c_diary_id']);
     }
 
-    $sql = 'SELECT COUNT(*) FROM c_diary WHERE c_member_id = ?';
+    $sql = 'SELECT COUNT(*) FROM ' . MYNETS_PREFIX_NAME . 'c_diary WHERE c_member_id = ?';
     $total_num = db_get_one($sql, $params);
 
     if ($total_num != 0) {
@@ -678,9 +697,9 @@ function k_p_fh_diary_list_c_diary_list4c_member_id($c_member_id, $page_size, $p
 function k_p_fh_diary_c_diary_comment_list4c_diary_id($c_diary_id, $page_size, $page, $page_sort = 0)
 {
     if ($page_sort == 0) {
-	$sql = 'SELECT * FROM c_diary_comment WHERE c_diary_id = ? ORDER BY r_datetime DESC';
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment WHERE c_diary_id = ? ORDER BY r_datetime DESC';
     } else {
-	$sql = 'SELECT * FROM c_diary_comment WHERE c_diary_id = ? ORDER BY r_datetime';
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment WHERE c_diary_id = ? ORDER BY r_datetime';
     }
     $params = array(intval($c_diary_id));
     $c_diary_comment_list = db_get_all_page($sql, $page, $page_size, $params);
@@ -691,14 +710,14 @@ function k_p_fh_diary_c_diary_comment_list4c_diary_id($c_diary_id, $page_size, $
         $c_diary_comment_list[$key]['image_filename'] = $c_member['image_filename'];
     }
     if ($page_sort != 0) {
-	$c_diary_comment_list = array_reverse($c_diary_comment_list);
+    $c_diary_comment_list = array_reverse($c_diary_comment_list);
     }
     
 
-		$total_page_num = 0;
-		$prev = false;
-		$next = false;
-    $sql = "SELECT COUNT(*) FROM c_diary_comment WHERE c_diary_id = ?";
+        $total_page_num = 0;
+        $prev = false;
+        $next = false;
+    $sql = "SELECT COUNT(*) FROM " . MYNETS_PREFIX_NAME . "c_diary_comment WHERE c_diary_id = ?";
     $params = array(intval($c_diary_id));
     $total_num = db_get_one($sql, $params);
 
@@ -720,7 +739,7 @@ function k_p_fh_diary_c_diary_comment_list4c_diary_id($c_diary_id, $page_size, $
 
 function test_k_p_fh_diary_c_diary_comment_list4c_diary_id($c_diary_id, $page_size, $page)
 {
-    $sql = 'SELECT * FROM c_diary_comment WHERE c_diary_id = ? ORDER BY r_datetime DESC';
+    $sql = 'SELECT * FROM ' . MYNETS_PREFIX_NAME . 'c_diary_comment WHERE c_diary_id = ? ORDER BY r_datetime DESC';
     $params = array(intval($c_diary_id));
     $c_diary_comment_list = db_get_all_page($sql, $page, $page_size, $params);
 
@@ -729,7 +748,7 @@ function test_k_p_fh_diary_c_diary_comment_list4c_diary_id($c_diary_id, $page_si
         $c_diary_comment_list[$key]['nickname'] = $c_member['nickname'];
     }
 
-    $sql = "SELECT COUNT(*) FROM c_diary_comment WHERE c_diary_id = ?";
+    $sql = "SELECT COUNT(*) FROM " . MYNETS_PREFIX_NAME . "c_diary_comment WHERE c_diary_id = ?";
     $params = array(intval($c_diary_id));
     $total_num = db_get_one($sql, $params);
 
@@ -755,7 +774,7 @@ function test_k_p_fh_diary_c_diary_comment_list4c_diary_id($c_diary_id, $page_si
 function k_p_fh_diary_c_member4c_diary_id($c_diary_id)
 {
     $sql = "SELECT cm.c_member_id, cm.nickname,cm. public_flag_diary ";
-    $sql .= " FROM c_member AS cm, c_diary AS cd ";
+    $sql .= " FROM " . MYNETS_PREFIX_NAME . "c_member AS cm, " . MYNETS_PREFIX_NAME . "c_diary AS cd ";
     $sql .= " WHERE cd.c_diary_id = ?";
     $sql .= " AND cm.c_member_id=cd.c_member_id";
     $params = array(intval($c_diary_id));
@@ -767,19 +786,19 @@ function k_p_fh_diary_c_member4c_diary_id($c_diary_id)
  */
 function k_p_h_home_c_diary_friend_list4c_member_id($c_member_id, $limit)
 {
-    $sql = "SELECT c_diary.*";
-    $sql .= " FROM c_diary, c_friend";
-    $sql .= " WHERE c_friend.c_member_id_from = ?";
-    $sql .= " AND c_diary.c_member_id=c_friend.c_member_id_to";
-    $sql .= " AND c_diary.public_flag <> 'private'";
-    $sql .= " ORDER BY c_diary.r_datetime DESC";
+    $sql = "SELECT cd.*";
+    $sql .= " FROM " . MYNETS_PREFIX_NAME . "c_diary as cd, " . MYNETS_PREFIX_NAME . "c_friend as cf";
+    $sql .= " WHERE cf.c_member_id_from = ?";
+    $sql .= " AND cd.c_member_id=cf.c_member_id_to";
+    $sql .= " AND cd.public_flag <> 'private'";
+    $sql .= " ORDER BY cd.r_datetime DESC";
     $params = array(intval($c_member_id));
     $c_diary_friend_list = db_get_all_limit($sql, 0, $limit, $params);
 
     foreach ($c_diary_friend_list as $key => $value) {
         $c_member = db_common_c_member4c_member_id_LIGHT($value['c_member_id']);
         $c_diary_friend_list[$key]['nickname'] = $c_member['nickname'];
-		
+        
     }
 
     return $c_diary_friend_list;
@@ -790,12 +809,12 @@ function k_p_h_home_c_diary_friend_list4c_member_id($c_member_id, $limit)
  */
 function k_p_h_diary_list_friend_h_diary_list_friend4c_member_id($c_member_id, $page_size, $page)
 {
-    $from = "c_diary, c_friend";
-    $where = "c_friend.c_member_id_from = ?" .
-            " AND c_diary.c_member_id = c_friend.c_member_id_to";
+    $from = MYNETS_PREFIX_NAME . "c_diary as cd, " . MYNETS_PREFIX_NAME . "c_friend as cf";
+    $where = "cf.c_member_id_from = ?" .
+            " AND cd.c_member_id = cf.c_member_id_to";
 
-    $sql = "SELECT c_diary.* FROM {$from} WHERE {$where}" .
-            " ORDER BY c_diary.r_datetime DESC";
+    $sql = "SELECT cd.* FROM {$from} WHERE {$where}" .
+            " ORDER BY cd.r_datetime DESC";
     $params = array(intval($c_member_id));
     $lst = db_get_all_page($sql, $page, $page_size, $params);
 
